@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2003  Albert Dorofeev <albert@tigr.net>
+ * Copyright (c) 1999-2007  Albert Dorofeev <albert@tigr.net>
  * For the updates see http://www.tigr.net/
  *
  * This software is distributed under GPL. For details see LICENSE file.
@@ -467,24 +467,25 @@ int read_meminfo()
 #else
 /* default /proc/meminfo (Linux) method ... */
 
-int getnum(FILE *fp, char *marker)
+unsigned long getnum(FILE *fp, char *marker)
 {
 	char thebuf[255];
 	int done = 0;
-	int theval;
+	unsigned long theval;
 
 	do {
 		if (fgets(thebuf, sizeof(thebuf), fp) == NULL) {
-			printf("file error\n");
-			return (-1);
+			fprintf(stderr, "asmem: failed to read number (%s) from the file\n", marker);
+			return (0);
 		
 		} else
 			if (strstr(thebuf, marker)) {
-				sscanf(thebuf, "%*s %d %*s\n",
+				sscanf(thebuf, "%*s %ld %*s\n",
 					&theval);
 				return (theval);
 			}
 	}while (!done);
+	return 0;
 }
 
 int read_meminfo()
@@ -530,7 +531,6 @@ int open_meminfo()
 
 #else
 #ifndef HAVE_UVM_UVM_EXTERN_H
-	int result;
 	if ((fp = fopen(state.proc_mem_filename, "r")) == NULL) {
 		error_handle(1, "");
 		return -1;
